@@ -21,9 +21,20 @@
    */
 
 #ifndef HSA_RUNTIME_WRAPPER_INC_AMD_HSA_QUEUE_H
-#define HSA_RUNTIME_WRAPPER_INC_AMD_HSA_QUEUE_H 
+#define HSA_RUNTIME_WRAPPER_INC_AMD_HSA_QUEUE_H
 
+#ifndef ROCM_HEADER_WRAPPER_WERROR
+#define ROCM_HEADER_WRAPPER_WERROR 0
+#endif
+#if ROCM_HEADER_WRAPPER_WERROR  /* ROCM_HEADER_WRAPPER_WERROR 1 */
+#error "amd_hsa_queue.h has moved to /opt/rocm/include/hsa and package include paths have changed.\nInclude as \"hsa/amd_hsa_queue.h\" when using cmake packages."
+#else  /* ROCM_HEADER_WRAPPER_WERROR 0 */
+#if defined(__GNUC__)
+#warning "amd_hsa_queue.h has moved to /opt/rocm/include/hsa and package include paths have changed.\nInclude as \"hsa/amd_hsa_queue.h\" when using cmake packages."
+#else
 #pragma message("amd_hsa_queue.h has moved to /opt/rocm/include/hsa and package include paths have changed.\nInclude as \"hsa/amd_hsa_queue.h\" when using cmake packages.")
+#endif
+#endif  /* ROCM_HEADER_WRAPPER_WERROR */
 #include "../../../include/hsa/amd_hsa_queue.h"
 
 
